abjadbooktools.AbjadBookScript
==============================

.. abjad-lineage:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript

.. autoclass:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.alias
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.output_formats
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.process_args
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__call__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__eq__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__ge__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__gt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__le__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__lt__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__ne__
   :noindex:

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__repr__
   :noindex:
